@@ -2,7 +2,7 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2012-2021                                       ###
+### Created by Martin Genet, 2012-2022                                       ###
 ###                                                                          ###
 ### University of California at San Francisco (UCSF), USA                    ###
 ### Swiss Federal Institute of Technology (ETH), Zurich, Switzerland         ###
@@ -10,17 +10,15 @@
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
 import dolfin
 import numpy
 import os
-import vtk
 
 import myPythonLibrary    as mypy
 import myVTKPythonLibrary as myvtk
 
 import dolfin_warp as dwarp
+
 from .generate_images import *
 
 ################################################################################
