@@ -2,16 +2,12 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-import dolfin
-
-import dolfin_warp as dwarp
-
 ################################################################################
 
 def get_ExprCharFuncIm_cpp_pybind(
